# SimSES
SimSES (Simulation of stationary energy storage systems) is an open source modeling framework for simulating stationary energy storage systems.

## Setup and installation

### 1. Create a virtual environment
Create a virtual environment, for example with either
[venv](https://packaging.python.org/en/latest/guides/installing-using-pip-and-virtual-environments/#creating-a-virtual-environment) or [conda](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html), or directly through your IDE like [PyCharm](https://www.jetbrains.com/help/pycharm/creating-virtual-environment.html#env-requirements) and [VS Code](https://code.visualstudio.com/docs/python/environments).

### 2. Install dependencies
Install `simses` and all other required python packages in your virtual environment. This can be done with a single command:
```
pip install -e .
```

## Aknowlegdements
The tool, originally developed in MATLAB, was initiated by Maik Naumann and Nam Truong, transferred to Python by Daniel Kucevic and Marc Möller and now continuously improved at the Chair of Electrical Energy Storage of the Technical University of Munich.